@@ -1,6 +1,6 @@
 #!/bin/sh
 #
-# Copyright (C) 2015-2021 Sébastien Helleu <flashcode@flashtux.org>
+# Copyright (C) 2015-2022 Sébastien Helleu <flashcode@flashtux.org>
 #
 # This file is part of WeeChat, the extensible chat client.
 #
@@ -32,9 +32,9 @@
 #     devel-patch  the patch version of devel (e.g. 2 for version 1.4.2)
 #
 
-WEECHAT_STABLE=3.2
-WEECHAT_DEVEL=3.2
-WEECHAT_DEVEL_FULL=3.2
+WEECHAT_STABLE=3.7
+WEECHAT_DEVEL=3.7
+WEECHAT_DEVEL_FULL=3.7
 
 if [ $# -lt 1 ]; then
     echo >&2 "Syntax: $0 stable|devel|devel-full|devel-major|devel-minor|devel-patch"
@@ -42,12 +42,12 @@ if [ $# -lt 1 ]; then
 fi
 
 case $1 in
-    stable ) echo $WEECHAT_STABLE ;;
-    devel ) echo $WEECHAT_DEVEL ;;
-    devel-full ) echo $WEECHAT_DEVEL_FULL ;;
-    devel-major ) echo $WEECHAT_DEVEL_FULL | cut -d'.' -f1 ;;
-    devel-minor ) echo $WEECHAT_DEVEL_FULL | cut -d'.' -f2 ;;
-    devel-patch ) echo $WEECHAT_DEVEL_FULL | cut -d'.' -f3- ;;
+    stable ) echo "$WEECHAT_STABLE" ;;
+    devel ) echo "$WEECHAT_DEVEL" ;;
+    devel-full ) echo "$WEECHAT_DEVEL_FULL" ;;
+    devel-major ) echo "$WEECHAT_DEVEL_FULL" | cut -d'.' -f1 ;;
+    devel-minor ) echo "$WEECHAT_DEVEL_FULL" | cut -d'.' -f2 ;;
+    devel-patch ) echo "$WEECHAT_DEVEL_FULL" | cut -d'.' -f3- ;;
     * ) echo >&2 "ERROR: unknown version."
         exit 1 ;;
 esac
